﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using TravelCompanyContracts.BindingModels.TouristBindingModels;
using TravelCompanyContracts.SearchModels.TouristSearchModels;
using TravelCompanyContracts.StoragesContracts.TouristStoragesContracts;
using TravelCompanyContracts.ViewModels.TouristViewModels;
using TravelCompanyDatabaseImplement.Models.TouristModel;

namespace TravelCompanyDatabaseImplement.Implements
{
    public class TravelStorage : ITravelStorage
    {
        public List<TravelViewModel> GetFullList()
        {
            using var context = new TravelCompanyDatabase();
            return context.Travels.Select(x => x.GetViewModel).ToList();
        }
        public List<TravelViewModel> GetFilteredList(TravelSearchModel
       model)
        {
            if (string.IsNullOrEmpty(model.TravelName))
            {
                return new();
            }
            using var context = new TravelCompanyDatabase();
            return context.Travels
            .Where(x => x.TravelName.Contains(model.TravelName))
           .Select(x => x.GetViewModel)
           .ToList();
        }
        public TravelViewModel? GetElement(TravelSearchModel model)
        {
            if (string.IsNullOrEmpty(model.TravelName) && !model.Id.HasValue)
            {
                return null;
            }
            using var context = new TravelCompanyDatabase();
            return context.Travels
            .FirstOrDefault(x =>
           !string.IsNullOrEmpty(model.TravelName) && x.TravelName ==
           model.TravelName ||
            model.Id.HasValue && x.Id == model.Id)
            ?.GetViewModel;
        }
        public TravelViewModel? Insert(TravelBindingModel model)
        {
            var newTravel = Travel.Create(model);
            if (newTravel == null)
            {
                return null;
            }
            using var context = new TravelCompanyDatabase();
            context.Travels.Add(newTravel);
            context.SaveChanges();
            return newTravel.GetViewModel;
        }
        public TravelViewModel? Update(TravelBindingModel model)
        {
            using var context = new TravelCompanyDatabase();
            var component = context.Travels.FirstOrDefault(x => x.Id == model.Id);
            if (component == null)
            {
                return null;
            }
            component.Update(model);
            context.SaveChanges();
            return component.GetViewModel;
        }
        public TravelViewModel? Delete(TravelBindingModel model)
        {
            using var context = new TravelCompanyDatabase();
            var element = context.Travels.FirstOrDefault(rec => rec.Id == model.Id);
            if (element != null)
            {
                context.Travels.Remove(element);
                context.SaveChanges();
                return element.GetViewModel;
            }
            return null;
        }
    }
}
